Version 0.1.1 (2014-12-22)
==========================

* Support for verifying signed SubscriptionConfirmation messages

Version 0.1.0 (2014-12-19)
==========================

* Misfit classes with data attributes
* Support for Python 3.x and PyPy
* Notification support (including SNS signature verification)
* MisfitAuth class to handle OAuth2
* Many squished bugs

Version 0.0.1 (2014-12-05)
==========================

* Initial release
